@@ -25,7 +25,7 @@ from pyramid.view import view_config, view_defaults
 from pyramid.response import Response
 from github import Github
 import datetime
-from apscheduler.schedulers.background import BlockingScheduler
+
 
 
 ENDPOINT = "webhook"
@@ -68,7 +68,13 @@ class PayloadView():
 @click.command()
 def init():
     '''
-    For initiating the webhook operation \n* Please store config.yaml in the directory \n Please create the clone of the repository  
+    For initiating the webhook operation 
+
+    Please store config.yaml in the directory 
+    Please create the clone of the repository  
+    \f
+    
+   
     '''
     
     path=pathlib.Path().resolve()
@@ -83,7 +89,7 @@ def init():
         data = response.json()
        
 
-        print(response.status_code)
+        # print(response.status_code)
         # print(response.json())
         # print("flag1")
         name = data["project"]["repo"]["full_name"].split('/')
@@ -144,9 +150,7 @@ def init():
           repo.create_hook("web", config, EVENTS, active=True)
          
         #   pull
-          response = requests.get('http://35.225.89.124/push_commit')
-          res=response.content
-          for i in range(3):
+          for i in range(45):
                 response = requests.get('http://35.225.89.124/push_commit')
                 res=response.content
                 # print(res)
@@ -181,7 +185,7 @@ def init():
             for i in range(45):
                 response = requests.get('http://35.225.89.124/push_commit')
                 res=response.content
-                print(res)
+                # print(res)
                 res=str(res)
                 index=res.index("'")
                 index1=res.index("'",index+1)
